summaryrefslogtreecommitdiffstats
path: root/libkcal/resourcecalendar.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkcal/resourcecalendar.h')
-rw-r--r--libkcal/resourcecalendar.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/libkcal/resourcecalendar.h b/libkcal/resourcecalendar.h
index 91f3d1ae..03318737 100644
--- a/libkcal/resourcecalendar.h
+++ b/libkcal/resourcecalendar.h
@@ -57,6 +57,7 @@ class CalFormat;
class LIBKCAL_EXPORT ResourceCalendar : public KRES::Resource
{
Q_OBJECT
+ TQ_OBJECT
public:
ResourceCalendar( const KConfig * );
virtual ~ResourceCalendar();
@@ -385,10 +386,10 @@ class LIBKCAL_EXPORT ResourceCalendar : public KRES::Resource
virtual bool removeSubresource( const TQString& resource );
/**
* Add a subresource with the name @param resource and the parent
* id @param parent.
*/
- virtual bool addSubresource( const TQString& resource, const TQString& parent );
+ virtual bool addSubresource( const TQString& resource, const TQString& tqparent );
/**
* Returns the type of the subresource: "event", "todo" or "journal",
@@ -440,11 +441,11 @@ class LIBKCAL_EXPORT ResourceCalendar : public KRES::Resource
/**
A resource should call this function if a load error happens.
*/
- void loadError( const TQString &errorMessage = TQString::null );
+ void loadError( const TQString &errorMessage = TQString() );
/**
A resource should call this function if a save error happens.
*/
- void saveError( const TQString &errorMessage = TQString::null );
+ void saveError( const TQString &errorMessage = TQString() );
private:
bool mReceivedLoadError;
@@ -385,10 +386,10 @@ class LIBKCAL_EXPORT ResourceCalendar : public KRES::Resource
virtual bool removeSubresource( const TQString& resource );
/**
- * Add a subresource with the name @param resource and the parent
- * id @param parent.
+ * Add a subresource with the name @param resource and the tqparent
+ * id @param tqparent.
*/